"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.versionCheck = exports.moduleExists = exports.defaultPlugins = void 0;
/* 默认加载的插件 */
exports.defaultPlugins = [
    ['@babel/plugin-proposal-decorators', { legacy: true }],
    '@babel/plugin-proposal-class-static-block',
    '@babel/plugin-proposal-class-properties',
    '@babel/plugin-proposal-do-expressions',
    '@babel/plugin-proposal-export-default-from',
    '@babel/plugin-proposal-export-namespace-from',
    '@babel/plugin-proposal-numeric-separator',
    ['@babel/plugin-proposal-pipeline-operator', { proposal: 'minimal' }],
    '@babel/plugin-proposal-throw-expressions',
    '@babel/plugin-syntax-module-string-names',
    '@babel/plugin-syntax-top-level-await' // top-level await
];
/* 判断模块是否存在 */
function moduleExists(id) {
    try {
        return require.resolve(id);
    }
    catch (err) {
        return false;
    }
}
exports.moduleExists = moduleExists;
/**
 * 模块版本检查是否大于等于指定的最小版本号
 * @param { string } version: 当前版本
 * @param { Array<number> } minimumVersion: 最小版本
 */
function versionCheck(version, minimumVersion) {
    const middleVersion = version.split(/\./);
    let result = true;
    for (let i = 0, j = minimumVersion.length; i < j; i++) {
        const lVer = Number(middleVersion[i]);
        const rVer = minimumVersion[i];
        if (lVer !== rVer) {
            result = lVer > rVer;
            break;
        }
    }
    return result;
}
exports.versionCheck = versionCheck;
